from __future__ import unicode_literals
import os

from pipedash.processor import BaseProcessor


class LessCompiler(BaseProcessor):

    input_extension = 'less'
    output_extension = 'css'

    @property
    def command(self):
        include_path = os.path.dirname(self.resolved_path)
        return ['lessc', '--include-path=%s' % include_path, '-']
